@@ -2449,10 +2449,10 @@ fn unescape_tpl_lit(s: &str) -> String {
                         continue;
                     }
 
-                    result.push_str("\\r");
+                    result.push_str("\r");
                 }
                 '\n' => {
-                    result.push_str("\\n");
+                    result.push_str("\n");
                 }
 
                 // TODO: Handle all escapes
